@@ -1,7 +1,7 @@
 <?php
 /* ========================================================================
  - [htdocs/mobile.php]
- -      Front Controller
+ -      携帯用のFront Controller
  -      Copyright (c) 2006 Yujiro Takahashi
  - ライセンス:
  -      This program is free software; you can redistribute it and/or
@@ -25,26 +25,91 @@
  - ======================================================================== */
 
 /* =-=- モジュール等の読み込み -=-= */
-require_once '../sns_config.php';
-require_once BASE_DIR.'mobapp'.DIRECTORY_SEPARATOR.'wap_config.php';
+include_once BASE_DIR.'mobapp'.DIRECTORY_SEPARATOR.'wap_config.php';
 
 define('WAP_DEFAULT_NUMBER', 5);
 
-// ------------------------------------------------
-// 実行関数
-// 引数         なし
-// 戻り値       なし
-// ------------------------------------------------
-function _main()
+/**
+ * セッションの開始
+ *
+ * @access public
+ * @return void
+ */
+function __session_start()
 {
     /* パスインフォからIDを取得 */
     $path_info = empty($_SERVER[PATH_INFO_KEY])?'':$_SERVER[PATH_INFO_KEY];
 
-    $args = explode('/',$path_info);
-    $group = empty($args[1])?'public':$args[1];
+    $args   = explode('/',$path_info);
+    $session_id = empty($args[4])?null:$args[4];
+
+    if (!preg_match('/'.SESSION_ID_PREFIX.'\w+/',$session_id)){
+        $session_id = null;
+    }
+    if (empty($session_id)){
+        $session_id = SESSION_ID_PREFIX.md5(time().$_SERVER['HTTP_USER_AGENT']);
+    }
+
+    include_once RKT_INCLUDE_ACCOUNT;
+    $func = array(RKT_ACCOUNT_CLASS, 'getInstance');
+    $objact = call_user_func($func, $session_id);
+}
+
+/**
+ * ログイン処理
+ *
+ * @access public
+ * @param reference $group
+ * @param reference $module
+ * @param reference $page
+ * @return boolean
+ */
+function __login_action(&$group,&$module,&$page)
+{
+    if ($page != 'login'){
+        return true;
+    }
+    include_once LIB_DIR.'rkt_auth.php';
+
+    $objauth = new RKT_auth();
+    if (!$objauth->logIn()){
+        $group  = 'public';
+        $module = 'login';
+        $page   = 'entrance';
+        $_GET['mismatch'] = 1;
+        return false;
+    }
+
+    $group  = 'private';
+    $module = 'home';
+    $page   = 'menu';
+
+    if (!empty($_REQUEST['url'])){
+        header('Location: '.$_REQUEST['url']);
+        exit();
+    }
+    
+    return true;
+}
+
+// ------------------------------------------------
+// フロントコントローラー
+// 引数         なし
+// 戻り値       なし
+// ------------------------------------------------
+function __controller()
+{
+    /* パスインフォからIDを取得 */
+    $path_info = empty($_SERVER[PATH_INFO_KEY])?'':$_SERVER[PATH_INFO_KEY];
+
+    $args   = explode('/',$path_info);
+    $group  = empty($args[1])?'public':$args[1];
     $module = empty($args[2])?'content':$args[2];
     $page   = empty($args[3])?$module:$args[3];
 
+    __session_start();                      // セッションの開始
+    __login_action($group,$module,$page);   // ログイン処理
+
     $titles = array (
         'admin'=>   array(
             'account'=>     array(      // アカウント管理
@@ -174,6 +239,7 @@ function _main()
         'private'=>   array(
             'account'=>     array(      // 会員情報
                 'account'=>     '会員基礎情報',
+                'autologin'=>   '自動ログイン登録',
                 'exit'=>        '退会処理',
                 'passwd'=>      'パスワード変更',
             ),
@@ -267,6 +333,7 @@ function _main()
         $page   = 'default';
     }
     $include = $group.'/'.$module.'/'.$page.'.php';
+
     include_once MODULE_DIR.$include;
 
     header('Content-Type: text/html; charset=Shift_JIS');
@@ -284,5 +351,4 @@ function _main()
         echo "</div>\n";
     }
 }
-_main();    // 実行関数
 ?>
