@@ -87,9 +87,9 @@ class WAP_friend extends RKT_webapp
     function WAP_friend()
     {
         $this->RKT_webapp();
-        $this->setPathInfo('sid', -1, 'string');
 
-        $objact = account::getInstance($this->sid);
+        $objact = account::getInstance();
+        $this->sid = $objact->getSessionID();
         $this->account = $objact->getInfo();
         $this->base['account'] = $this->account;
 
