@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/13] 公開フラグをビットフラグに対応
  -      [2007/02/03] 市区町村条件指定エラーの修正
  -      [2006/07/10] 作成
  - ======================================================================== */
@@ -226,21 +227,18 @@ class webapp extends WAP_private
             $age_flag = true;
         }
         if ($age_flag){
-            $where[] = '(pro.age_flag='.VISIBILITY_PUBLIC.
-                            ' OR pro.age_flag='.VISIBILITY_PROTECTED.')';
+            $where[] = 'pro.age_flag & '.$this->visibility;
         }
 
         /* 血液型 */
         if (!empty($conditions['ref_blood'])){
             $where[] = 'pro.ref_blood='.$conditions['ref_blood'];
-            $where[] = '(pro.blood_flag='.VISIBILITY_PUBLIC.
-                            ' OR pro.blood_flag='.VISIBILITY_PROTECTED.')';
+            $where[] = 'pro.blood_flag & '.$this->visibility;
         }
         /* 現住所 */
         if (!empty($conditions['ref_prefecture'])){
             $where[] = 'pro.ref_prefecture='.$conditions['ref_prefecture'];
-            $where[] = '(pro.prefecture_flag='.VISIBILITY_PUBLIC.
-                            ' OR pro.prefecture_flag='.VISIBILITY_PROTECTED.')';
+            $where[] = 'pro.prefecture_flag & '.$this->visibility;
         }
         if (!empty($conditions['ref_local'])){
             $where[] = 'pro.ref_local='.$conditions['ref_local'];
@@ -248,8 +246,7 @@ class webapp extends WAP_private
         /* 出身地 */
         if (!empty($conditions['ref_hometown'])){
             $where[] = 'pro.ref_hometown='.$conditions['ref_hometown'];
-            $where[] = '(pro.hometown_flag='.VISIBILITY_PUBLIC.
-                            ' OR pro.hometown_flag='.VISIBILITY_PROTECTED.')';
+            $where[] = 'pro.hometown_flag & '.$this->visibility;
         }
         if (!empty($conditions['ref_homelocal'])){
             $where[] = 'pro.ref_homelocal='.$conditions['ref_homelocal'];
@@ -257,8 +254,7 @@ class webapp extends WAP_private
         /* 未婚/既婚 */
         if (!empty($conditions['ref_married'])){
             $where[] = 'pro.ref_married='.$conditions['ref_married'];
-            $where[] = '(pro.married_flag='.VISIBILITY_PUBLIC.
-                            ' OR pro.married_flag='.VISIBILITY_PROTECTED.')';
+            $where[] = 'pro.married_flag & '.$this->visibility;
         }
         /* アンケート */
         if (!empty($conditions['ref_item'])){
@@ -267,8 +263,7 @@ class webapp extends WAP_private
             } else {
                 $where[] = 'con.ref_item='.$conditions['ref_item'];
             }
-            $where[] = '(con.visibility='.VISIBILITY_PUBLIC.
-                            ' OR con.visibility='.VISIBILITY_PROTECTED.')';
+            $where[] = sql_query::bitFlag('con.visibility & '.$this->visibility);
         }
         $select = array();
         if (!empty($conditions['ref_select'])){
@@ -276,8 +271,7 @@ class webapp extends WAP_private
                 $select[] = implode(',',$selected);
             }
             $where[] = 'sel.ref_item in('.implode(',',$select).')';
-            $where[] = '(sel.visibility='.VISIBILITY_PUBLIC.
-                            ' OR sel.visibility='.VISIBILITY_PROTECTED.')';
+            $where[] = sql_query::bitFlag('sel.visibility & '.$this->visibility);
         }
         /* キーワード検索 */
         $keys = array();
