@@ -21,6 +21,8 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/06/17] アクセス権限定義を追加
+ -      [2007/06/08] manip(ulation)用DBクラス保存ディレクトリパス定義を追加
  -      [2007/05/28] 管理者と初期ユーザーを統合
  -      [2007/04/21] 問合せ対応状況を追加
  -      [2007/02/12] STATUS_COMMUNITYをビットフラグ
@@ -128,6 +130,7 @@ define('DB_DIR', WORK_DIR.'dbs'.DIRECTORY_SEPARATOR);               // データ
 define('THEME_DIR', WORK_DIR.'themes'.DIRECTORY_SEPARATOR);         // デザインテーマ保存ディレクトリパス
 define('RESOURCE_DIR',DOCUMENT_DIR.'resource'.DIRECTORY_SEPARATOR); // リソースファイルの保存先パス
 define('CACHE_IMG_DIR', CACHE_DIR.'img'.DIRECTORY_SEPARATOR);       // テンポラリイメージ保存ディレクトリパス
+define('MANIP_DIR', WORK_DIR.'manips'.DIRECTORY_SEPARATOR);         // manip(ulation)用DBクラス保存ディレクトリパス
 define('ARCHIVES_DIR','');                                          // アーカイブスの保存先パス
 define('MEMBER_DIR',ARCHIVES_DIR.'account'.DIRECTORY_SEPARATOR);        // アーカイブスの保存先パス
 define('COMMUNITY_DIR',ARCHIVES_DIR.'community'.DIRECTORY_SEPARATOR);   // アーカイブスの保存先パス
@@ -223,6 +226,12 @@ define('VISIBILITY_LABEL_PUBLIC_ENTRY',  '参加条件はありません(ネッ
 define('VISIBILITY_LABEL_PRIVATE_ENTRY', '参加には管理者の承認が必要です (会員に公開)');
 define('VISIBILITY_LABEL_HIDDEN_ENTRY',  '参加には管理者の承認が必要です(非公開)');
 
+/* ---------------------------------------- */
+/* アクセス権限 */
+define('PERMISSION_ADMIN',    1);                                   // 管理者のみ
+define('PERMISSION_MEMBER',   2);                                   // 会員まで
+define('PERMISSION_GUEST',    3);                                   // ゲスト
+
 /* ---------------------------------------- */
 /* ニュースの配信の状態 */
 define('NEWS_STOP',   0);                                           // 配信停止
