@@ -156,6 +156,27 @@ class dia_menu
         $this->objhtml->Assign('menu', $this->menu);
     }
 
+    /**
+     * ゲスト用メニュー設定
+     *
+     * @access public
+     * @param integer $audience
+     * @return void
+     */
+    function setMenuGuest()
+    {
+        $this->publicity = VISIBILITY_PUBLIC;
+        $this->menu['target'] = 'public';
+        $this->menu['ref_friend'] = $this->ref_account;
+
+        $this->set_calendar();
+        $this->set_days();
+        $this->set_archives();
+        $this->set_category();
+        
+        $this->objhtml->Assign('menu', $this->menu);
+    }
+
     /**
      * 閲覧者判定の設定
      *
@@ -260,13 +281,16 @@ class dia_menu
                 $day_format.' as day,'.
                 'ent.subject as subject '.
             'FROM '.
+                DB_PREFIX.'dia_diary dia,'.
                 DB_PREFIX.'dia_entry ent '.
             'WHERE '.
+                'dia.id = ent.ref_diary AND '.
                 'ent.ref_diary = '.$this->diary['id'].' AND '.
                 $month_format." = '".$date."' AND ".
+                sql_query::bitFlag('dia.visibility & '.$this->visibility).' AND '.
                 sql_query::bitFlag('ent.visibility & '.$this->visibility).' '.
             'GROUP BY '.
-                'regist_date';
+                'ent.regist_date';
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
@@ -297,9 +321,12 @@ class dia_menu
                 'count(ent.id) as ct,'.
                 $date_format.' as month '.
             'FROM '.
+                DB_PREFIX.'dia_diary dia,'.
                 DB_PREFIX.'dia_entry ent '.
             'WHERE '.
+                'dia.id = ent.ref_diary AND '.
                 'ent.ref_diary = '.$this->diary['id'].' AND '.
+                sql_query::bitFlag('dia.visibility & '.$this->visibility).' AND '.
                 sql_query::bitFlag('ent.visibility & '.$this->visibility).' '.
             'GROUP BY '.
                 'month '.
@@ -326,13 +353,16 @@ class dia_menu
                 'count(sel.ref_entry) as ct,'.
                 'cat.category as category '.
             'FROM '.
+                DB_PREFIX.'dia_diary dia,'.
                 DB_PREFIX.'dia_entry ent,'.
                 DB_PREFIX.'dia_category cat,'.
                 DB_PREFIX.'dia_select sel '.
             'WHERE '.
+                'dia.id = ent.ref_diary AND '.
                 'ent.id = sel.ref_entry AND '.
                 'cat.id = sel.ref_category AND '.
                 'cat.ref_diary = '.$this->diary['id'].' AND '.
+                sql_query::bitFlag('dia.visibility & '.$this->visibility).' AND '.
                 sql_query::bitFlag('ent.visibility & '.$this->visibility).' '.
             'GROUP BY '.
                 'cat.id '.
