@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/06/17] コミュニティ：トピック、イベント、記事、アンケート権限追加
  -      [2007/01/30] カテゴリ選択更新時エラーを修正
  -      [2006/08/27] コミュニティカテゴリを複数選択対応
  -      [2006/08/27] 基礎情報を親クラスから引っ張るように修正
@@ -166,7 +167,6 @@ class webapp extends WAP_community
         } else {
             $this->objmnp->setValue('regist_date', date('Y-m-d H:i:s'));
             $this->objmnp->setValue('total', 1);
-            $this->objmnp->setValue('topic_flag', VISIBILITY_PROTECTED);
         }
 
         /* 直接入力 */
@@ -183,8 +183,8 @@ class webapp extends WAP_community
         /* 入力フォームからをキャッチ */
         $skip = array(
             'regist_date',
-            'topic_flag',
             'total',
+            'access_num',
         );
         return $this->objmnp->execute($this,$skip);
     }
