@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/06/16] 日記の公開レベルを追加
  -      [2007/02/13] フォーマットがWYSIWYGエディタならジャンプ
  -      [2007/02/02] カテゴリ選択更新時エラーを修正
  -      [2006/09/25] sns_dia_entry.link を更新しないように変更
@@ -149,6 +150,14 @@ class webapp extends WAP_private
 
         $this->set_category();
         $this->Assign('picture', $objpic->getImgInfos());
+
+        $visibilitys = array(
+            VISIBILITY_PUBLIC=>    VISIBILITY_LABEL_PUBLIC,
+            VISIBILITY_PROTECTED=> VISIBILITY_LABEL_PROTECTED,
+            VISIBILITY_FRIEND=>    VISIBILITY_LABEL_FRIEND,
+            VISIBILITY_HIDDEN=>    VISIBILITY_LABEL_HIDDEN,
+        );
+        $this->Assign('visibilitys', $visibilitys);
     }
 
     /**
@@ -242,7 +251,6 @@ class webapp extends WAP_private
         // 直接入力
         $this->objmnp->setValue('modify', date('Y-m-d H:i:s'));
         $this->objmnp->setValue('ref_diary', $this->ref_diary);
-        $this->objmnp->setValue('visibility', VISIBILITY_PROTECTED);
         $this->objmnp->setValue('format', DIARY_FORMAT_PLAIN);
 
         /* 初期値への加工設定 */
