@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/06/16] 日記の公開レベルを追加
  -      [2007/03/11] 本文の入力データのエスケープ処理を変更
  -      [2007/02/02] 本文の初期値、改行部分を修正
  -      [2007/02/02] カテゴリ選択更新時エラーを修正
@@ -154,6 +155,14 @@ class webapp extends WAP_private
 
         $this->set_category();
         $this->Assign('picture', $objpic->getImgInfos());
+
+        $visibilitys = array(
+            VISIBILITY_PUBLIC=>    VISIBILITY_LABEL_PUBLIC,
+            VISIBILITY_PROTECTED=> VISIBILITY_LABEL_PROTECTED,
+            VISIBILITY_FRIEND=>    VISIBILITY_LABEL_FRIEND,
+            VISIBILITY_HIDDEN=>    VISIBILITY_LABEL_HIDDEN,
+        );
+        $this->Assign('visibilitys', $visibilitys);
     }
 
     /**
@@ -303,7 +312,6 @@ class webapp extends WAP_private
         /* 直接入力 */
         $this->objmnp->setValue('modify', date('Y-m-d H:i:s'));
         $this->objmnp->setValue('ref_diary', $this->ref_diary);
-        $this->objmnp->setValue('visibility', VISIBILITY_PROTECTED);
         $this->objmnp->setValue('format', DIARY_FORMAT_HTML);
 
         /* 入力データの加工設定 */
