@@ -68,6 +68,8 @@ class webapp extends WAP_public
         $this->set_friend();
         $this->set_community();
         $this->set_community_number();
+
+        $this->set_diary();
     }
 
     /**
@@ -518,5 +520,71 @@ class webapp extends WAP_public
 
         $this->Assign('community_num',$result['ct']);
     }
+
+    /**
+     * 日記情報の取得
+     *
+     * @access private
+     * @return interger     データ操作結果
+     */
+    function get_diary_visibility()
+    {
+        $sql=
+            'SELECT '.
+                'id '.
+            'FROM '.
+                DB_PREFIX.'dia_diary '.
+            'WHERE '.
+                'ref_account ='.$this->ref_friend.' AND '.
+                sql_query::bitFlag('visibility & '.VISIBILITY_PUBLIC);
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO::FETCH_ASSOC);
+        $stmt->closeCursor();
+        if (empty($result)){
+            return false;
+        }
+        return true;
+    }
+
+    /**
+     * 日記の設定
+     *
+     * @access private
+     * @return void
+     */
+    function set_diary()
+    {
+        if (!$this->get_diary_visibility()){
+            return ;
+        }
+        $sql=
+            'SELECT '.
+                'ent.id as ref_entry,'.
+                'act.id as ref_friend,'.
+                'pro.nickname as nickname,'.
+                'ent.regist_date as modify,'.
+                'ent.subject as subject '.
+            'FROM '.
+                DB_PREFIX.'act_account act,'.
+                DB_PREFIX.'act_profile pro,'.
+                DB_PREFIX.'dia_diary dia,'.
+                DB_PREFIX.'dia_entry ent '.
+            'WHERE '.
+                'act.id = pro.ref_account AND '.
+                'act.id = dia.ref_account AND '.
+                'dia.id = ent.ref_diary AND '.
+                'act.avail = '.AVAIL_ENABLE.' AND '.
+                'dia.ref_account = '.$this->ref_friend.' AND '.
+                sql_query::bitFlag('ent.visibility & '.VISIBILITY_PUBLIC).' '.
+            'ORDER BY '.
+                'ent.regist_date DESC '.
+            'LIMIT 5';
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+
+        $this->Assign('diarys', $result);
+    }
 } // webapp
 ?>
