@@ -20,6 +20,8 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/06/17] コミュニティ：トピック、イベント、記事、アンケート権限追加
+--      [2007/06/17] コミュニティ：アクセス、足跡追加
 --      [2007/05/27] 会員携帯用自動ログインを追加
 --      [2007/04/21] 問合せ内容を修正、問合せ対応を追加
 --      [2007/02/02] 日記の未読コメントflagを追加
@@ -793,11 +795,15 @@ CREATE TABLE `sns_com_community` (
   `avail` int(11),
   `visibility` int(11) NOT NULL,
   `topic_flag` int(11) NOT NULL,
+  `event_flag` int(11) NOT NULL,
+  `item_flag` int(11) NOT NULL,
+  `enquete_flag` int(11) NOT NULL,
   `community` varchar(128) NOT NULL,
   `ref_prefecture` int(11) NOT NULL,
   `url` varchar(128),
   `publicity` text NOT NULL,
   `total` int(11),
+  `access_num` int(11),
   PRIMARY KEY  (`id`)
 ) TYPE=MyISAM AUTO_INCREMENT=1;
 
@@ -922,6 +928,29 @@ CREATE TABLE `sns_com_picture` (
   PRIMARY KEY  (`id`)
 ) TYPE=MyISAM AUTO_INCREMENT=1;
 
+-- 
+-- コミュニティのアクセスログ
+-- 
+CREATE TABLE `sns_com_accesslog` (
+  `id` int(11) unsigned NOT NULL auto_increment,
+  `modify` timestamp NOT NULL,
+  `ref_community` int(11) NOT NULL,
+  `ref_account` int(11) NOT NULL,
+  `unique_flag` int(11) NOT NULL,
+  PRIMARY KEY  (`id`)
+) TYPE=MyISAM AUTO_INCREMENT=1;
+
+-- 
+-- コミュニティへの足跡
+-- 
+CREATE TABLE `sns_com_footprint` (
+  `id` int(11) unsigned NOT NULL auto_increment,
+  `modify` timestamp NOT NULL,
+  `ref_community` int(11) NOT NULL,
+  `ref_account` int(11) NOT NULL,
+  PRIMARY KEY  (`id`)
+) TYPE=MyISAM AUTO_INCREMENT=1;
+
 -- --------------------------------------------------------
 -- 
 -- 問合せカテゴリのマスター情報
