@@ -20,6 +20,8 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/06/17] コミュニティ：トピック、イベント、記事、アンケート権限追加
+--      [2007/06/17] コミュニティ：アクセス、足跡追加
 --      [2007/05/27] 会員携帯用自動ログインを追加
 --      [2007/04/21] 問合せ内容を修正、問合せ対応を追加
 --      [2007/02/02] 日記の未読コメントflagを追加
@@ -779,11 +781,15 @@ CREATE TABLE 'sns_com_community' (
   'avail' integer,
   'visibility' integer NOT NULL,
   'topic_flag' integer NOT NULL,
+  'event_flag' integer NOT NULL,
+  'item_flag' integer NOT NULL,
+  'enquete_flag' integer NOT NULL,
   'community' varchar(128) NOT NULL,
   'ref_prefecture' integer NOT NULL,
   'url' varchar(128),
   'publicity' text NOT NULL,
   'total' integer,
+  'access_num' integer,
   PRIMARY KEY  ('id')
 );
 
@@ -908,6 +914,28 @@ CREATE TABLE 'sns_com_picture' (
   PRIMARY KEY  ('id')
 );
 
+-- 
+-- コミュニティのアクセスログ
+-- 
+CREATE TABLE 'sns_com_accesslog' (
+  'id' integer NOT NULL,
+  'modify' timestamp NOT NULL,
+  'ref_community' integer NOT NULL,
+  'ref_account' integer NOT NULL,
+  'unique_flag' integer NOT NULL,
+  PRIMARY KEY  ('id')
+);
+
+-- 
+-- コミュニティへの足跡
+-- 
+CREATE TABLE 'sns_com_footprint' (
+  'id' integer NOT NULL,
+  'modify' timestamp NOT NULL,
+  'ref_community' integer NOT NULL,
+  'ref_account' integer NOT NULL,
+  PRIMARY KEY  ('id')
+);
 
 -- --------------------------------------------------------
 -- 
